@@ -6,10 +6,10 @@ local ffi_new = ffi.new
 local ffi_str = ffi.string
 local C = ffi.C
 local setmetatable = setmetatable
-local error = error
+--local error = error
 
 
-local _M = { _VERSION = '0.09' }
+local _M = { _VERSION = '0.10' }
 
 local mt = { __index = _M }
 
