@@ -5,11 +5,11 @@ local ffi = require "ffi"
 local ffi_new = ffi.new
 local ffi_str = ffi.string
 local C = ffi.C
-local setmetatable = setmetatable
-local error = error
+--local setmetatable = setmetatable
+--local error = error
 
 
-local _M = { _VERSION = '0.09' }
+local _M = { _VERSION = '0.10' }
 
 
 ffi.cdef[[
